@@ -368,12 +368,19 @@ class GroupingRecordProvider(object):
         else:
             return None
 
-    def export_to_xls(self, title, columns, total, grouped, expanded, sorting):
-        '''
-        выгрузка таблицы в xls-файл
-        '''
+    def _tune_xls_worksheet(self, worksheet):
+        """
+        Здесь можно задать нужные параметры страницы.
+        """
+        return worksheet
+
+    def export_to_xls (self, title, columns, total, grouped, expanded, sorting):
+        """
+        Выгрузка таблицы в xls-файл
+        """
         w = xlwt.Workbook()
         ws = w.add_sheet('grid')
+        ws = self._tune_xls_worksheet(ws)
 
         title_style = xlwt.easyxf(self.xls_style.get(
             'title') or "font: bold on, height 400;")
@@ -1286,4 +1293,4 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
                     return mult * result
             else:
                 return 0
-        return sorted(items, cmp=comparer)
\ No newline at end of file
+        return sorted(items, cmp=comparer)
